@@ -10,6 +10,7 @@ use Socket6 (); # to ensure dependency is met
 use HTML::Entities (); # to ensure dependency is met
 use URI::QueryParam (); # part of URI, to add helper methods
 use Path::Class 'dir';
+use Module::Load ();
 use App::Netdisco::Util::Web 'interval_to_daterange';
 
 use App::Netdisco::Web::AuthN;
@@ -34,8 +35,7 @@ sub _load_web_plugins {
       $plugin =~ s/^\+//;
 
       debug "loading Netdisco plugin $plugin";
-      eval "require $plugin";
-      error $@ if $@;
+      Module::Load::load $plugin;
   }
 }
 
@@ -48,6 +48,10 @@ if (setting('extra_web_plugins') and ref [] eq ref setting('extra_web_plugins'))
     _load_web_plugins( setting('extra_web_plugins') );
 }
 
+# after plugins are loaded, add our own template path
+push @{ config->{engines}->{netdisco_template_toolkit}->{INCLUDE_PATH} },
+     setting('views');
+
 # workaround for https://github.com/PerlDancer/Dancer/issues/935
 hook after_error_render => sub { setting('layout' => 'main') };
 
